NNN50 WIFI_API library

Dependents:   NNN50_CE_Test_UDP NNN50_linux_firmware NNN50_SoftAP_HelloWorld NNN50_BLEWIFISensor ... more

This is mbed compatible EthernetInterface lib exclude for Delta DFCM-NNN50 platform.

Additional information and examples can be found in mbed Handbook

Revision:
1:be6abb24f013
Parent:
0:06fccc63b33d
Child:
9:32d6cd2f8456
--- a/WIFIDevice.h	Wed Nov 23 17:36:49 2016 +0000
+++ b/WIFIDevice.h	Sat Dec 03 15:24:52 2016 +0000
@@ -40,22 +40,18 @@
   */
   void setNetwork(uint8_t secType, char* SSID, char* PW);
 
   /** Set Access Point in given configuration.
   * Set SSID, password, security type and channel in AP mode.
   * \param SSID name of access point in AP mode
   * \param PW password of the given SSID
-  * \param security tyoe of security in AP mode (default: (SECURITY_WPA2_AES_PSK)), support
-     SECURITY_OPEN          < Open security >
-     SECURITY_WEP_PSK       < WEP Security with open authentication with 5/13 ascii characters or 10/26 hex codes passwords
-     SECURITY_WEP_SHARED    < WEP Security with shared authentication with 5/13 ascii characters or 10/26 hex codes passwords
-     SECURITY_WPA_TKIP_PSK  < WPA Security with TKIP with 8 or more ascii characters passwords
-     SECURITY_WPA_AES_PSK   < WPA Security with AES with 8 or more ascii characters passwords 
-     SECURITY_WPA2_AES_PSK  < WPA2 Security with AES with 8 or more ascii characters passwords  
-     SECURITY_WPA2_TKIP_PSK < WPA2 Security with TKIP with 8 or more ascii characters passwords
-     SECURITY_WPA2_MIXED_PSK< WPA2 Security with AES & TKIP with 8 or more ascii characters passwords
+  * \param AP_ip the IP address of AP
+  * \param security tyoe of security in AP mode (default: (M2M_WIFI_SEC_WEP)), support
+    M2M_WIFI_SEC_OPEN       < Open security >
+    M2M_WIFI_SEC_WEP        < Security type WEP with 10 hexadecimal digits >
   * \param channel range from 1 to 14 (default: (1))
+  * \return 0 on success, a negative number on failure  
   */
-  //void WIFIDevice::setAccessPoint(char* SSID, char* PW, uint8_t secType, uint8_t channel=1);
+  int WIFIDevice::enableAccessPoint(char* SSID, char* PW, char* AP_ip = "192.168.1.1", uint8_t secType=M2M_WIFI_SEC_WEP, uint8_t channel=1);
 
   /** Erase a 4KB sector of embeeded flash.
   * Flash memory will be erased in groups of 4KB sector.
@@ -87,3 +83,4 @@
 int enableCoexistance();
 
 #endif /* WIFIDEVICE_H_ */
+
@@ -40,22 +40,18 @@
   void setNetwork(uint8_t secType, char* SSID, char* PW);
 
-  /** Set Access Point in given configuration.
+  /** Enable Access Point in given configuration.
   * Set SSID, password, security type and channel in AP mode.
   * \param SSID name of access point in AP mode